@@ -5,14 +5,14 @@ package Crypt::TEA_PP;
 use strict;
 use warnings;
 use utf8;
-use integer;
+use bigint;
 
 use Carp;
 use List::Util qw(all);
 
 use vars qw ($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 
 my $DELTA = 0x9e3779b9;
@@ -90,7 +90,7 @@ sub encrypt_block {
         $block[0] = ( $block[0] + ( ( ( ( ( ( ( ( $block[1] << 4 ) & 0xffff_ffff ) + $key[0] ) & 0xffff_ffff ) ^ ( ( $block[1] + $sumation ) & 0xffff_ffff ) ) & 0xffff_ffff ) ^ ( ( ( ( $block[1] >> 5 ) & 0xffff_ffff ) +  $key[1] ) & 0xffff_ffff ) ) & 0xffff_ffff ) ) & 0xffff_ffff;
         $block[1] = ( $block[1] + ( ( ( ( ( ( ( ( $block[0] << 4 ) & 0xffff_ffff ) + $key[2] ) & 0xffff_ffff ) ^ ( ( $block[0] + $sumation ) & 0xffff_ffff ) ) & 0xffff_ffff ) ^ ( ( ( ( $block[0] >> 5 ) & 0xffff_ffff ) +  $key[3] ) & 0xffff_ffff ) ) & 0xffff_ffff ) ) & 0xffff_ffff;
         #printf("\t--> Encrypting block round %d of %d\n", $i + 1, $ROUNDS);
-        printf("\t--> block[0] = %d, block[1] = %d\n", $block[0], $block[1]);
+        #printf("\t--> block[0] = %d, block[1] = %d\n", $block[0], $block[1]);
     }
     return \@block;
 }
@@ -139,7 +139,7 @@ Crypt::TEA_PP - Pure Perl Implementation of the Tiny Encryption Algorithm
 
 =head1 VERSION
 
-version 0.0201
+version 0.03
 
 =head1 SYNOPSIS
 
